@@ -3,5 +3,5 @@
 """Top-level package for Clockify API Python client."""
 
 __author__ = """Sjoerd Kerkstra"""
-__email__ = 'sjoerdk1@xs4all.nl'
-__version__ = '0.1.11'
+__email__ = "sjoerdk1@xs4all.nl"
+__version__ = "0.2.2"
